@@ -22,14 +22,17 @@ import json
 import logging
 import os
 from dataclasses import dataclass
+from itertools import filterfalse
 from typing import Any, Dict, List, Optional, Tuple, cast
 
-import boto3
 from botocore import client
 from ruamel.yaml import YAML
+from ruamel.yaml.composer import ComposerError
 from ruamel.yaml.parser import ParserError
 from ruamel.yaml.scanner import ScannerError
 
+from panther_analysis_tool.util import get_client
+
 logger = logging.getLogger(__file__)
 
 
@@ -38,13 +41,14 @@ class Client:
     _LIST_SCHEMAS_ENDPOINT = "ListSchemas"
     _PUT_SCHEMA_ENDPOINT = "PutUserSchema"
 
-    def __init__(self) -> None:
+    def __init__(self, aws_profile: str) -> None:
         self._lambda_client = None
+        self._aws_profile = aws_profile
 
     @property
     def lambda_client(self) -> client.BaseClient:
         if self._lambda_client is None:
-            self._lambda_client = boto3.client("lambda")
+            self._lambda_client = get_client(self._aws_profile, "lambda")
         return self._lambda_client
 
     def list_schemas(self) -> Tuple[bool, dict]:
@@ -143,16 +147,17 @@ class Uploader:
     _SCHEMA_NAME_PREFIX = "Custom."
     _SCHEMA_FILE_GLOB_PATTERNS = ("*.yml", "*.yaml")
 
-    def __init__(self, path: str):
+    def __init__(self, path: str, aws_profile: str):
         self._path = path
         self._files: Optional[List[str]] = None
         self._api_client: Optional[Client] = None
         self._existing_schemas: Optional[List[Dict[str, Any]]] = None
+        self._aws_profile = aws_profile
 
     @property
     def api_client(self) -> Client:
         if self._api_client is None:
-            self._api_client = Client()
+            self._api_client = Client(self._aws_profile)
         return self._api_client
 
     @property
@@ -163,7 +168,8 @@ class Uploader:
             A list of absolute paths to the schema files.
         """
         if self._files is None:
-            self._files = discover_files(self._path, self._SCHEMA_FILE_GLOB_PATTERNS)
+            matching_filenames = discover_files(self._path, self._SCHEMA_FILE_GLOB_PATTERNS)
+            self._files = ignore_schema_test_files(matching_filenames)
         return self._files
 
     @property
@@ -179,7 +185,10 @@ class Uploader:
             success, response = self.api_client.list_schemas()
             if not success:
                 raise RuntimeError("unable to retrieve custom schemas")
-            self._existing_schemas = response["results"]
+            if "results" in response:
+                self._existing_schemas = response["results"]
+            else:
+                self._existing_schemas = []
         return self._existing_schemas
 
     def find_schema(self, name: str) -> Optional[Dict[str, Any]]:
@@ -264,7 +273,7 @@ class Uploader:
                 with open(filename, "r") as schema_file:
                     processed_file.raw = schema_file.read()
                 processed_file.yaml = yaml_parser.load(processed_file.raw)
-            except (ParserError, ScannerError) as exc:
+            except (ParserError, ScannerError, ComposerError) as exc:
                 processed_file.error = f"invalid YAML: {exc}"
         return processed_files
 
@@ -342,6 +351,60 @@ def discover_files(base_path: str, patterns: Tuple[str, ...]) -> List[str]:
     return sorted(files)
 
 
+def ignore_schema_test_files(paths: List[str]) -> List[str]:
+    """
+    Detect and ignore files that contain schema tests.
+
+    Args:
+        paths: the list of file paths from which schema test files will be excluded
+
+    Returns:
+        The list of absolute paths of files that possibly contain custom schema definitions.
+    """
+    return list(filterfalse(_contains_schema_tests, paths))
+
+
+def _contains_schema_tests(filename: str) -> bool:
+    """
+    Check if a file contains YAML document(s) that describe test cases for custom schemas.
+    Note that a test case file may contain multiple YAML documents.
+
+    Args:
+        filename: the full path for the file to be checked
+
+    Returns:
+        True if the fields match the test case definition structure
+        and the filename suffix & extension match the constraints imposed by pantherlog.
+    """
+    # pantherlog requires that files containing test cases have a specific suffix and extension:
+    # https://github.com/panther-labs/panther-enterprise/blob/75dd7ac2be67d3388edabb914b87f514ea9bd2cf/internal/log_analysis/log_processor/logtypes/logtesting/logtesting.go#L302
+    if not filename.endswith("_tests.yml"):
+        return False
+
+    yaml_parser = YAML(typ="safe")
+
+    with open(filename, "r") as stream:
+        try:
+            yaml_documents: List[Dict[str, Any]] = yaml_parser.load_all(stream)
+        except (ParserError, ScannerError, ComposerError):
+            return False
+
+        documents = list(yaml_documents)
+
+    if not documents:
+        return False
+
+    fields = set(map(str.lower, documents[0].keys()))
+
+    # - "input" and "logtype" are expected to be always present
+    # - at least one of "result", "results" fields is required
+    return {"input", "logtype", "result"}.issubset(fields) or {
+        "input",
+        "logtype",
+        "results",
+    }.issubset(fields)
+
+
 def normalize_path(path: str) -> Optional[str]:
     """Resolve the given path to its absolute form, taking into
     account user home prefix notation.
