@@ -28,9 +28,9 @@ import os
 import re
 import subprocess  # nosec
 import sys
-import tempfile
 import zipfile
 from collections import defaultdict
+from collections.abc import Mapping
 from dataclasses import asdict
 from datetime import datetime
 from distutils.util import strtobool
@@ -42,8 +42,8 @@ from uuid import uuid4
 
 import botocore
 import requests
-import semver
-from ruamel.yaml import YAML
+from dynaconf import Dynaconf, Validator
+from ruamel.yaml import YAML, SafeConstructor, constructor
 from ruamel.yaml import parser as YAMLParser
 from ruamel.yaml import scanner as YAMLScanner
 from schema import (
@@ -61,7 +61,7 @@ from panther_analysis_tool.destination import FakeDestination
 from panther_analysis_tool.enriched_event import PantherEvent
 from panther_analysis_tool.exceptions import UnknownDestinationError
 from panther_analysis_tool.log_schemas import user_defined
-from panther_analysis_tool.policy import Policy
+from panther_analysis_tool.policy import TYPE_POLICY, Policy
 from panther_analysis_tool.rule import Detection, Rule
 from panther_analysis_tool.schemas import (
     DATA_MODEL_SCHEMA,
@@ -80,6 +80,7 @@ from panther_analysis_tool.testing import (
 )
 from panther_analysis_tool.util import get_client
 
+CONFIG_FILE = ".panther_settings.yml"
 DATA_MODEL_LOCATION = "./data_models"
 HELPERS_LOCATION = "./global_helpers"
 
@@ -131,10 +132,11 @@ SET_FIELDS = [
     "Tags",
 ]
 
-# Environment Variables
-# -- Activates sub-commands that are meant for internal use --
-ENV_VAR_INCLUDE_INTERNAL_SUBCOMMANDS = "PANTHER_PAT_INCLUDE_INTERNAL_SUBCOMMANDS"
-
+# interpret datetime as str, the backend uses the default behavior for json.loads, which
+# interprets these as str.  This sets global config for ruamel SafeConstructor
+constructor.SafeConstructor.add_constructor(
+    "tag:yaml.org,2002:timestamp", SafeConstructor.construct_yaml_str
+)
 
 # exception for conflicting ids
 class AnalysisIDConflictException(Exception):
@@ -179,17 +181,24 @@ def load_module(filename: str) -> Tuple[Any, Any]:
     return module, None
 
 
-def load_analysis_specs(directories: List[str]) -> Iterator[Tuple[str, str, Any, Any]]:
+def load_analysis_specs(
+    directories: List[str], ignore_files: List[str]
+) -> Iterator[Tuple[str, str, Any, Any]]:
     """Loads the analysis specifications from a file.
 
     Args:
         directories: The relative path to Panther policies or rules.
+        ignore_files: Files that Panther Analysis Tool should not process
 
     Yields:
         A tuple of the relative filepath, directory name, and loaded analysis specification dict.
     """
     # setup a list of paths to ensure we do not import the same files
     # multiple times, which can happen when testing from root directory without filters
+    ignored_normalized = []
+    for file in ignore_files:
+        ignored_normalized.append(os.path.normpath(file))
+
     loaded_specs: List[Any] = []
     for directory in directories:
         for relative_path, _, file_list in os.walk(directory):
@@ -230,6 +239,11 @@ def load_analysis_specs(directories: List[str]) -> Iterator[Tuple[str, str, Any,
                 # skip loading files that have already been imported
                 if spec_filename in loaded_specs:
                     continue
+                # Dont load files that are explictly ignored
+                relative_name = os.path.normpath(os.path.join(relative_path, filename))
+                if relative_name in ignored_normalized:
+                    logging.info("ignoring file %s", relative_name)
+                    continue
                 loaded_specs.append(spec_filename)
                 if fnmatch(filename, "*.y*ml"):
                     with open(spec_filename, "r") as spec_file_obj:
@@ -309,7 +323,9 @@ def zip_analysis(args: argparse.Namespace) -> Tuple[int, str]:
         analysis = []
         files: Set[str] = set()
         for (file_name, f_path, spec, _) in list(
-            load_analysis_specs([args.path, HELPERS_LOCATION, DATA_MODEL_LOCATION])
+            load_analysis_specs(
+                [args.path, HELPERS_LOCATION, DATA_MODEL_LOCATION], args.ignore_files
+            )
         ):
             if file_name not in files:
                 analysis.append((file_name, f_path, spec))
@@ -666,6 +682,7 @@ def test_analysis(args: argparse.Namespace) -> Tuple[int, list]:
     """
     logging.info("Testing analysis packs in %s\n", args.path)
 
+    ignored_files = args.ignore_files
     search_directories = [args.path]
 
     # Try the parent directory as well
@@ -684,7 +701,9 @@ def test_analysis(args: argparse.Namespace) -> Tuple[int, list]:
             search_directories.append(absolute_helper_path)
 
     # First classify each file, always include globals and data models location
-    specs, invalid_specs = classify_analysis(list(load_analysis_specs(search_directories)))
+    specs, invalid_specs = classify_analysis(
+        list(load_analysis_specs(search_directories, ignore_files=ignored_files))
+    )
 
     if all((len(specs[key]) == 0 for key in specs)):
         if invalid_specs:
@@ -1122,7 +1141,9 @@ def _run_tests(  # pylint: disable=too-many-arguments
                     for each_mock in mocks
                     if "objectName" in each_mock and "returnValue" in each_mock
                 }
-            test_case = PantherEvent(entry, analysis_data_models.get(log_type))
+            test_case: Mapping = entry
+            if detection.detection_type.upper() != TYPE_POLICY.upper():
+                test_case = PantherEvent(entry, analysis_data_models.get(log_type))
             if mock_methods:
                 with patch.multiple(detection.module, **mock_methods):
                     result = detection.run(test_case, {}, destinations_by_name, batch_mode=False)
@@ -1161,7 +1182,7 @@ def _run_tests(  # pylint: disable=too-many-arguments
 def _print_test_result(
     detection: Detection, test_result: TestResult, failed_tests: DefaultDict[str, list]
 ) -> None:
-    status_pass = "PASS" # nosec
+    status_pass = "PASS"  # nosec
     status_fail = "FAIL"
     if test_result.passed:
         outcome = status_pass
@@ -1263,6 +1284,16 @@ def setup_parser() -> argparse.ArgumentParser:
         "type": strtobool,
         "help": "Meant for advanced users; allows skipping of extra keys from schema validation.",
     }
+    ignore_files_name = "--ignore-files"
+    ignore_files_arg: Dict[str, Any] = {
+        "required": False,
+        "dest": "ignore_files",
+        "nargs": "+",
+        "help": "Relative path to files in this project to be ignored by panther-analysis tool, "
+        + "space separated. Example ./foo.yaml ./bar/baz.yaml",
+        "type": str,
+        "default": [],
+    }
     available_destination_name = "--available-destination"
     available_destination_arg: Dict[str, Any] = {
         "required": False,
@@ -1278,7 +1309,7 @@ def setup_parser() -> argparse.ArgumentParser:
         + "managing Panther policies and rules.",
         prog="panther_analysis_tool",
     )
-    parser.add_argument("--version", action="version", version="panther_analysis_tool 0.10.1")
+    parser.add_argument("--version", action="version", version="panther_analysis_tool 0.10.4")
     parser.add_argument("--debug", action="store_true", dest="debug")
     subparsers = parser.add_subparsers()
 
@@ -1290,6 +1321,7 @@ def setup_parser() -> argparse.ArgumentParser:
     )
     release_parser.add_argument(aws_profile_name, **aws_profile_arg)
     release_parser.add_argument(filter_name, **filter_arg)
+    release_parser.add_argument(ignore_files_name, **ignore_files_arg)
     release_parser.add_argument(kms_key_name, **kms_key_arg)
     release_parser.add_argument(min_test_name, **min_test_arg)
     release_parser.add_argument(out_name, **out_arg)
@@ -1306,13 +1338,14 @@ def setup_parser() -> argparse.ArgumentParser:
     test_parser.add_argument(min_test_name, **min_test_arg)
     test_parser.add_argument(path_name, **path_arg)
     test_parser.add_argument(ignore_extra_keys_name, **ignore_extra_keys_arg)
+    test_parser.add_argument(ignore_files_name, **ignore_files_arg)
     test_parser.add_argument(skip_disabled_test_name, **skip_disabled_test_arg)
     test_parser.add_argument(available_destination_name, **available_destination_arg)
     test_parser.set_defaults(func=test_analysis)
 
     publish_parser = subparsers.add_parser(
         "publish",
-        help="Publishes a new release, generates the release assets, and uploads them"
+        help="Publishes a new release, generates the release assets, and uploads them. "
         + "Generates a file called panther-analysis-all.zip and optionally generates "
         + "panther-analysis-all.sig",
     )
@@ -1354,6 +1387,7 @@ def setup_parser() -> argparse.ArgumentParser:
     publish_parser.add_argument(skip_test_name, **skip_test_arg)
     publish_parser.add_argument(skip_disabled_test_name, **skip_disabled_test_arg)
     publish_parser.add_argument(available_destination_name, **available_destination_arg)
+    publish_parser.add_argument(ignore_files_name, **ignore_files_arg)
     publish_parser.set_defaults(func=publish_release)
 
     upload_parser = subparsers.add_parser(
@@ -1367,6 +1401,7 @@ def setup_parser() -> argparse.ArgumentParser:
     upload_parser.add_argument(skip_test_name, **skip_test_arg)
     upload_parser.add_argument(skip_disabled_test_name, **skip_disabled_test_arg)
     upload_parser.add_argument(ignore_extra_keys_name, **ignore_extra_keys_arg)
+    upload_parser.add_argument(ignore_files_name, **ignore_files_arg)
     upload_parser.add_argument(available_destination_name, **available_destination_arg)
     upload_parser.set_defaults(func=upload_analysis)
 
@@ -1379,104 +1414,54 @@ def setup_parser() -> argparse.ArgumentParser:
     update_custom_schemas_parser.add_argument(path_name, **custom_schemas_path_arg)
     update_custom_schemas_parser.set_defaults(func=update_custom_schemas)
 
-    if os.environ.get(ENV_VAR_INCLUDE_INTERNAL_SUBCOMMANDS):
-        update_managed_schemas_parser = subparsers.add_parser(
-            "update-schemas", help="Update managed schemas on a Panther deployment."
-        )
-        update_managed_schemas_parser.add_argument(aws_profile_name, **aws_profile_arg)
-        update_managed_schemas_parser.set_defaults(func=update_schemas)
-
-        zip_parser = subparsers.add_parser(
-            "zip", help="Create an archive of local policies and rules for uploading to Panther."
-        )
-        zip_parser.add_argument(filter_name, **filter_arg)
-        zip_parser.add_argument(min_test_name, **min_test_arg)
-        zip_parser.add_argument(out_name, **out_arg)
-        zip_parser.add_argument(path_name, **path_arg)
-        zip_parser.add_argument(skip_test_name, **skip_test_arg)
-        zip_parser.add_argument(skip_disabled_test_name, **skip_disabled_test_arg)
-        zip_parser.add_argument(available_destination_name, **available_destination_arg)
-        zip_parser.set_defaults(func=zip_analysis)
-
-        zip_schemas_parser = subparsers.add_parser(
-            "zip-schemas", help="Create a release asset archive of managed schemas."
-        )
-        zip_schemas_parser.add_argument(
-            "--release", type=str, help="The release tag this asset is for", required=True
-        )
-        zip_schemas_parser.add_argument(out_name, **out_arg)
-        zip_schemas_parser.set_defaults(func=zip_managed_schemas)
+    zip_parser = subparsers.add_parser(
+        "zip", help="Create an archive of local policies and rules for uploading to Panther."
+    )
+    zip_parser.add_argument(filter_name, **filter_arg)
+    zip_parser.add_argument(ignore_files_name, **ignore_files_arg)
+    zip_parser.add_argument(min_test_name, **min_test_arg)
+    zip_parser.add_argument(out_name, **out_arg)
+    zip_parser.add_argument(path_name, **path_arg)
+    zip_parser.add_argument(skip_test_name, **skip_test_arg)
+    zip_parser.add_argument(skip_disabled_test_name, **skip_disabled_test_arg)
+    zip_parser.add_argument(available_destination_name, **available_destination_arg)
+    zip_parser.set_defaults(func=zip_analysis)
 
     return parser
 
 
-def zip_managed_schemas(args: argparse.Namespace) -> Tuple[int, str]:
-    """Packs managed schemas of a tagged release into a local zip file.
+def setup_dynaconf() -> Dict[str, Any]:
+    config_file_settings_raw = Dynaconf(
+        settings_file=CONFIG_FILE,
+        envvar_prefix="PANTHER",
+        validators=[
+            Validator("AWS_PROFILE", is_type_of=str),
+            Validator("MINIMUM_TESTS", is_type_of=int),
+            Validator("OUT", is_type_of=str),
+            Validator("PATH", is_type_of=str),
+            Validator("SKIP_TEST", is_type_of=bool),
+            Validator("SKIP_DISABLED_TESTS", is_type_of=bool),
+            Validator("IGNORE_FILES", is_type_of=(str, list)),
+            Validator("AVAILABLE_DESTINATION", is_type_of=(str, list)),
+            Validator("KMS_KEY", is_type_of=str),
+            Validator("BODY", is_type_of=str),
+            Validator("GITHUB_BRANCH", is_type_of=str),
+            Validator("GITHUB_OWNER", is_type_of=str),
+            Validator("GITHUB_REPOSITORY", is_type_of=str),
+            Validator("GITHUB_TAG", is_type_of=str),
+            Validator("FILTER", is_type_of=dict),
+        ],
+    )
+    # Dynaconf stores its keys in ALL CAPS
+    return {k.lower(): v for k, v in config_file_settings_raw.as_dict().items()}
 
-    Args:
-        args: The populated Argparse namespace with parsed command-line arguments.
 
-    Returns:
-        A tuple of return code and the archive filename.
-    """
+def dynaconf_argparse_merge(
+    argparse_dict: Dict[str, Any], config_file_settings: Dict[str, Any]
+) -> None:
 
-    manifest = []
-    with tempfile.TemporaryDirectory(prefix="zip-managed-schemas-") as tmp_dir:
-        repo_url = "https://github.com/panther-labs/panther-analysis"
-        repo_dir = os.path.join(tmp_dir, "panther-analysis")
-        rel = args.release
-        if not semver.VersionInfo.isvalid(rel[1:] if rel.startswith("v") else rel):
-            logging.error("Invalid release tag %s", rel)
-            return 1, ""
-
-        logging.info("Cloning %s tag of %s", rel, repo_url)
-        # nosec
-        cmd = [
-            "git",
-            "clone",
-            "--branch",
-            rel,
-            "--depth",
-            "1",
-            "-c",
-            "advice.detachedHead=false",
-            repo_url,
-            repo_dir,
-        ]
-        result = subprocess.run(cmd, check=True, timeout=120)  # nosec
-        if result.returncode != 0:
-            return result.returncode, ""
-
-        schema_dir = os.path.join(repo_dir, "schemas")
-        filenames = [
-            os.path.join(root, f)
-            for root, dirs, files in os.walk(schema_dir)
-            if not fnmatch(root, "*/tests")
-            for f in files
-            if fnmatch(f, "*.yml")
-        ]
-        if not filenames:
-            logging.error("Release %s does not contain any managed schema file", rel)
-            return 1, ""
-
-        logging.info(
-            "Building manifest.yml for %d managed schemas found in release %s", len(filenames), rel
-        )
-        for filename in filenames:
-            with open(filename) as yml:
-                lines = yml.readlines()
-                manifest.append("---\n")
-                manifest.extend(lines)
-
-    archive = os.path.join(args.out, "managed-schemas-{}.zip".format(rel))
-    logging.info("Zipping release asset archive %s", archive)
-    with zipfile.ZipFile(archive, "w", zipfile.ZIP_DEFLATED) as zip_out:
-        # Set the archive comment to the release version
-        zip_out.comment = bytes(rel, encoding="utf8")
-        # Add the manifest.yml file
-        zip_out.writestr("manifest.yml", "".join(manifest))
-
-    return 0, archive
+    for key, value in config_file_settings.items():
+        argparse_dict[key] = value
 
 
 # Parses the filters, expects a list of strings
@@ -1528,6 +1513,17 @@ def run() -> None:
     if getattr(args, "filter_inverted", None) is None:
         args.filter_inverted = {}
 
+    if os.path.exists(CONFIG_FILE):
+        logging.info(
+            "Found Config File %s . NOTE: SETTINGS IN CONFIG FILE OVERRIDE COMMAND LINE OPTIONS",
+            CONFIG_FILE,
+        )
+        config_file_settings = setup_dynaconf()
+        dynaconf_argparse_merge(vars(args), config_file_settings)
+        if args.debug:
+            for key, value in vars(args).items():
+                logging.debug(f"{key}={value}")  # pylint: disable=W1203
+
     # Although not best practice, the alternative is ugly and significantly harder to maintain.
     if bool(getattr(args, "ignore_extra_keys", None)):
         RULE_SCHEMA._ignore_extra_keys = True  # pylint: disable=protected-access
