@@ -17,9 +17,8 @@ You should have received a copy of the GNU Affero General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
 
-from typing import List
+from collections.abc import Mapping
 
-from panther_analysis_tool.enriched_event import PantherEvent
 from panther_analysis_tool.rule import Detection
 
 TYPE_POLICY = "POLICY"
@@ -37,9 +36,6 @@ class Policy(Detection):
     # a policy should trigger an alert on False return value
     matcher_alert_value = False
 
-    # suppressions for the policy
-    suppressions: List[str] = []
-
-    def matcher_function(self, event: PantherEvent) -> bool:
+    def matcher_function(self, event: Mapping) -> bool:
         command = getattr(self._module, self.matcher_function_name)
         return self._run_command(command, event, bool)
